@@ -56,6 +56,8 @@ def create_project(projectName):
     create_pipeline_file(projectName, 'labelizer')
     create_pipeline_file(projectName, 'pipeline')
 
+    create_preproccesor_vocab_folder()
+    create_project_config_yaml()
 
     create_testet_file(projectName, 'dataset')
     create_testet_file(projectName, 'reporter')
@@ -128,5 +130,19 @@ def create_tester_init_file(init_path, init_export):
     f.write("\n")
     f.close()
 
+def create_preproccesor_vocab_folder():
+    currentDir = directory + '/preprocessor/vocab'
+    if not os.path.exists(currentDir):
+        os.mkdir(currentDir)
+
+def create_project_config_yaml():
+    with open(os.path.join(__location__, 'cli/config.yaml'), 'r') as file:
+        data = file.read()
+        data = data.replace('generatedDirectory', directory)
+        new_file = directory + '/pipeline/config.yaml'
+        if not os.path.exists(new_file):
+            f = open(new_file, "w")
+            f.write(data)
+            f.close()
 if __name__ == '__main__':
     cli(prog_name='cli')
