@@ -1,6 +1,8 @@
 from typing import Dict, Any, List
-from dsFramework import PreprocessorBase, ZIDSConfig, SharedArtifacts
-from dsFramework.base_classes import PredictableBase
+from dsframework.pipeline import PreprocessorBase
+from dsframework.config import ZIDSConfig
+from dsframework.shared import SharedArtifacts
+from dsframework.base_classes import PredictableBase
 
 class generatedClass(PreprocessorBase):
     def __init__(self, config: ZIDSConfig, shared_artifacts: SharedArtifacts, name: str = 'generatedClassName',
