@@ -1,6 +1,6 @@
-from dsFramework.utils.regex_handler import RegexHandler
+from dsframework.utils.regex_handler import RegexHandler
 from generatedDirectory.pipeline import generatedProjectNamePipeline
-from dsFramework.testable import TesterBase
+from dsframework.testable.tester_base import TesterBase
 from generatedDirectory.tester import generatedProjectNameDataset
 from generatedDirectory.tester import generatedProjectNameReporter
 import pandas as pd
@@ -65,88 +65,91 @@ class generatedClass(TesterBase):
             self.dataset.populate()
 
     def get_report_df_cols(self):
-        def get_cols_per_attr(attr):
-            return [f'{attr}_pred', f'{attr}_target', f'{attr}_prob', f'{attr}_tp',  f'{attr}_fp',  f'{attr}_tn', f'{attr}_fn']
-        
-        cols = []
-        cols+= ['name_prefix', 'name_first', 'name_middle', 'name_last', 'name_suffix', 'name_credentials']
-        cols+= ['tc_title', 'tc_company']
-        cols+= ['connections_phones', 'connections_mobiles', 'connections_faxes', 'connections_urls', 'connections_emails']
-        cols+= ['location_address', 'location_city', 'location_state', 'location_zip', 'location_country']
-        
-        self.report_base_cols = cols
-        cols_per_attr = [get_cols_per_attr(attr) for attr in cols]
-        flatten = lambda l: [item for sublist in l for item in sublist]
-        cols_as_list = flatten(cols_per_attr)
-        report_cols = ['text', 'pred', 'target'] + cols_as_list
-        return report_cols
+        # def get_cols_per_attr(attr):
+        #     return [f'{attr}_pred', f'{attr}_target', f'{attr}_prob', f'{attr}_tp',  f'{attr}_fp',  f'{attr}_tn', f'{attr}_fn']
+        #
+        # cols = []
+        # cols+= ['name_prefix', 'name_first', 'name_middle', 'name_last', 'name_suffix', 'name_credentials']
+        # cols+= ['tc_title', 'tc_company']
+        # cols+= ['connections_phones', 'connections_mobiles', 'connections_faxes', 'connections_urls', 'connections_emails']
+        # cols+= ['location_address', 'location_city', 'location_state', 'location_zip', 'location_country']
+        #
+        # self.report_base_cols = cols
+        # cols_per_attr = [get_cols_per_attr(attr) for attr in cols]
+        # flatten = lambda l: [item for sublist in l for item in sublist]
+        # cols_as_list = flatten(cols_per_attr)
+        # report_cols = ['text', 'pred', 'target'] + cols_as_list
+        # return report_cols
+        raise NotImplementedError
 
     def evaluate(self, sample):
-        def get_metrics(pred='', target=''):
-            TP = 1*all([len(pred), len(target), pred==target])
-            FP = 1*all([len(pred), pred!=target])
-            TN = 1*all([not len(pred), not len(target), pred==target])
-            FN = 1*all([not len(pred), len(target), pred!=target])
-            return [TP, FP, TN, FN]
-            
-        text   = sample.x
-        pred   = sample.pred
-        target = sample.y
+        # def get_metrics(pred='', target=''):
+        #     TP = 1*all([len(pred), len(target), pred==target])
+        #     FP = 1*all([len(pred), pred!=target])
+        #     TN = 1*all([not len(pred), not len(target), pred==target])
+        #     FN = 1*all([not len(pred), len(target), pred!=target])
+        #     return [TP, FP, TN, FN]
+        #
+        # text   = sample.x
+        # pred   = sample.pred
+        # target = sample.y
+        #
+        # pred_copy = copy.deepcopy(pred)
+        # target_copy = copy.deepcopy(target)
+        #
+        # connections_pred   = self.convert_lists_to_str(pred_copy.get('connections', {}))
+        # connections_target = self.convert_lists_to_str(target_copy.get('connections', {}))
+        #
+        # pred_copy['connections'] = connections_pred
+        # target_copy['connections'] = connections_target
+        #
+        # # pred['connections'] = connections_pred
+        # # target['connections'] = connections_target
+        #
+        # preds_dict  = self.F.flatten(pred)
+        # target_dict = self.F.flatten(target)
+        # pred_copy_dict  = self.F.flatten(pred_copy)
+        # target_copy_dict = self.F.flatten(target_copy)
+        #
+        # # if not self.is_valid_signature(target_dict):
+        # #     return None
+        # row = [text, pred, target]
+        #
+        # if not self.report_base_cols:
+        #     self.report_col_names = self.get_report_df_cols()
+        #
+        # for key in self.report_base_cols:
+        #     prob       = -1
+        #     pred_val   = preds_dict.get(key, '')
+        #     target_val = target_dict.get(key, '')
+        #     pred_val_c   = self.normalize_val_for_compare(pred_copy_dict.get(key, ''))
+        #     target_val_c = self.normalize_val_for_compare(target_copy_dict.get(key, ''))
+        #     metrices     = [pred_val, target_val, prob] + get_metrics(pred_val_c, target_val_c)
+        #     row+=metrices
+        #
+        # return row
+        raise NotImplementedError
 
-        pred_copy = copy.deepcopy(pred)
-        target_copy = copy.deepcopy(target)
-
-        connections_pred   = self.convert_lists_to_str(pred_copy.get('connections', {}))
-        connections_target = self.convert_lists_to_str(target_copy.get('connections', {}))
-
-        pred_copy['connections'] = connections_pred
-        target_copy['connections'] = connections_target
-
-        # pred['connections'] = connections_pred
-        # target['connections'] = connections_target
-
-        preds_dict  = self.F.flatten(pred)
-        target_dict = self.F.flatten(target)
-        pred_copy_dict  = self.F.flatten(pred_copy)
-        target_copy_dict = self.F.flatten(target_copy)
-
-        # if not self.is_valid_signature(target_dict):
-        #     return None
-        row = [text, pred, target]
-
-        if not self.report_base_cols:
-            self.report_col_names = self.get_report_df_cols()
-
-        for key in self.report_base_cols:
-            prob       = -1
-            pred_val   = preds_dict.get(key, '')
-            target_val = target_dict.get(key, '')
-            pred_val_c   = self.normalize_val_for_compare(pred_copy_dict.get(key, ''))
-            target_val_c = self.normalize_val_for_compare(target_copy_dict.get(key, ''))
-            metrices     = [pred_val, target_val, prob] + get_metrics(pred_val_c, target_val_c)
-            row+=metrices
-
-        return row
-
-    def convert_lists_to_str(self, d = {}):
-        def list_to_str(k, v):
-            val = [RegexHandler.remove_punct(str(t)).lower().replace(' ','') for t in v]
-            val = list(set(val))
-            val.sort()
-            s = ''.join(val).strip()
-            s = ''.join(list(set(s)))
-            s = ''.join(sorted(s))
-            if 'phone' in k :
-                s = ''.join([c for c in s if c.isdigit()])
-            else:
-                s=s.replace('w','') # to ensure no www is considered + no order matters and no duplicates
-            return s
-
-        for k, v in d.items():
-            if type(v) is list:
-                d[k] = list_to_str(k, v)
-
-        return d
+    def convert_lists_to_str(self, d={}):
+        # def list_to_str(k, v):
+        #     val = [RegexHandler.remove_punct(str(t)).lower().replace(' ','') for t in v]
+        #     val = list(set(val))
+        #     val.sort()
+        #     s = ''.join(val).strip()
+        #     s = ''.join(list(set(s)))
+        #     s = ''.join(sorted(s))
+        #     if 'phone' in k :
+        #         s = ''.join([c for c in s if c.isdigit()])
+        #     else:
+        #         s=s.replace('w','') # to ensure no www is considered + no order matters and no duplicates
+        #     return s
+        #
+        # for k, v in d.items():
+        #     if type(v) is list:
+        #         d[k] = list_to_str(k, v)
+        #
+        # return d
+        raise NotImplementedError
 
     def is_valid_signature(self, target_dict):
         company_exist    = len(target_dict.get('tc_company', ''))>0
