@@ -6,23 +6,27 @@ with open('requirements.txt') as f:
 
 setup(
     name='dsFramework',
-    py_modules=['api_cli', 'dsFramework'],
+    py_modules=['api_cli'],
+    # packages=find_packages(),
+    # packages=find_packages(where="./lib")
+    # + find_packages(where="./cli"),
     packages=[
         'cli',
         'cli.tester',
-        'lib',
-        'lib.base_classes',
-        'lib.config',
-        'lib.pipeline',
-        'lib.shared',
-        'lib.utils',
-        'lib.testable',
+        'dsframework',
+        'dsframework.base_classes',
+        'dsframework.config',
+        'dsframework.pipeline',
+        'dsframework.shared',
+        'dsframework.utils',
+        'dsframework.testable',
     ],
+    package_data={'': ['config.yaml']},
     entry_points='''
         [console_scripts]
         ds-framework-cli=api_cli:cli
     ''',
-    version='0.1.14',
+    version='0.1.15',
     description='My first Python library',
     # url='http://pypi.python.org/pypi/PackageName/',
     author='oribrau@gmail.com',
